@@ -29,7 +29,6 @@
 #include <errno.h>
 #include <stdio.h>
 #include <jpeglib.h>
-#include "shhopt.h"
 #include "ppm.h"
 
 #define EXIT_WARNING 2   /* Goes with EXIT_SUCCESS, EXIT_FAILURE in stdlib.h */
@@ -86,7 +85,7 @@ static boolean set_sample_factors (j_compress_ptr cinfo, char *arg);
 
 
 
-void
+int
 main(const int argc, char ** argv) {
   struct jpeg_compress_struct cinfo;
   struct jpeg_error_mgr jerr;
@@ -228,7 +227,9 @@ main(const int argc, char ** argv) {
   if (input_file != stdin)
     fclose(input_file);
 
-  /* All done. */
+  /* Program may have exited with non-zero completion code vie various function
+     calls above.
+     */
   exit((jerr.num_warnings > 0) ? EXIT_WARNING : EXIT_SUCCESS);
 }
 
@@ -323,15 +324,6 @@ parse_command_line(const int argc, char ** argv,
     char ** const argv_parse = malloc(argc*sizeof(char *));
     /* argv, except we modify it as we parse */
 
-    /* Create the OptStruct structure describing our options */
-    #define OPTENTRY(shortvalue,longvalue,typevalue,outputvalue,flagvalue) {\
-      option_def[option_def_index].shortName = (shortvalue); \
-      option_def[option_def_index].longName = (longvalue); \
-      option_def[option_def_index].type = (typevalue); \
-      option_def[option_def_index].arg = (outputvalue); \
-      option_def[option_def_index].flags = (flagvalue); \
-      option_def_index++; \
-      }
     option_def_index = 0;   /* incremented by OPTENTRY */
     OPTENTRY(0, "verbose",     OPT_FLAG,   &cmdline_p->verbose,        0);
     OPTENTRY(0, "quality",     OPT_UINT,   &cmdline_p->quality,        0);
@@ -351,7 +343,6 @@ parse_command_line(const int argc, char ** argv,
     OPTENTRY(0, "optimize",    OPT_FLAG,   &cmdline_p->optimize,       0);
     OPTENTRY(0, "optimise",    OPT_FLAG,   &cmdline_p->optimize,       0);
     OPTENTRY(0, "restart",     OPT_STRING, &restart,                   0);
-    option_def[option_def_index].type = OPT_END; 
 
     /* Set the defaults */
     cmdline_p->verbose = FALSE;
@@ -371,11 +362,11 @@ parse_command_line(const int argc, char ** argv,
     cmdline_p->optimize = FALSE;
     restart = NULL;
 
-  /* Make private copy of arguments for optParseOptions to corrupt */
+    /* Make private copy of arguments for optParseOptions to corrupt */
     argc_parse = argc;
     for (i=0; i < argc; i++) argv_parse[i] = argv[i];
 
-    optParseOptions(&argc_parse, argv_parse, option_def, 0);
+    pm_optParseOptions(&argc_parse, argv_parse, option_def, 0);
     /* Uses and sets argc_parse, argv_parse and all of *cmdline_p. */
 
     if (argc_parse - 1 == 0)
